==> credentials-2.1.13-sources.jar: com/cloudbees/plugins/credentials/fingerprints/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.plugins.credentials.fingerprints;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code AbstractCredentialsFingerprintFacet.timestampRange}: {@code
     * Used {1} ago (first used {0} ago)}.
     * 
     * @param arg1
     *      2nd format parameter, {@code {1}}, as {@link String#valueOf(Object)}.
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Used {1} ago (first used {0} ago)}
     */
    public static String AbstractCredentialsFingerprintFacet_timestampRange(Object arg0, Object arg1) {
        return holder.format("AbstractCredentialsFingerprintFacet.timestampRange", arg0, arg1);
    }

    /**
     * Key {@code AbstractCredentialsFingerprintFacet.timestampRange}: {@code
     * Used {1} ago (first used {0} ago)}.
     * 
     * @param arg1
     *      2nd format parameter, {@code {1}}, as {@link String#valueOf(Object)}.
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Used {1} ago (first used {0} ago)}
     */
    public static Localizable _AbstractCredentialsFingerprintFacet_timestampRange(Object arg0, Object arg1) {
        return new Localizable(holder, "AbstractCredentialsFingerprintFacet.timestampRange", arg0, arg1);
    }

    /**
     * Key {@code AbstractCredentialsFingerprintFacet.timestampSingle}:
     * {@code Used {0} ago}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Used {0} ago}
     */
    public static String AbstractCredentialsFingerprintFacet_timestampSingle(Object arg0) {
        return holder.format("AbstractCredentialsFingerprintFacet.timestampSingle", arg0);
    }

    /**
     * Key {@code AbstractCredentialsFingerprintFacet.timestampSingle}:
     * {@code Used {0} ago}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Used {0} ago}
     */
    public static Localizable _AbstractCredentialsFingerprintFacet_timestampSingle(Object arg0) {
        return new Localizable(holder, "AbstractCredentialsFingerprintFacet.timestampSingle", arg0);
    }

}

==> credentials-2.3.19-sources.jar: com/cloudbees/plugins/credentials/fingerprints/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.plugins.credentials.fingerprints;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code AbstractCredentialsFingerprintFacet.timestampRange}: {@code
     * Used {1} ago (first used {0} ago)}.
     * 
     * @param arg1
     *      2nd format parameter, {@code {1}}, as {@link String#valueOf(Object)}.
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Used {1} ago (first used {0} ago)}
     */
    public static String AbstractCredentialsFingerprintFacet_timestampRange(Object arg0, Object arg1) {
        return holder.format("AbstractCredentialsFingerprintFacet.timestampRange", arg0, arg1);
    }

    /**
     * Key {@code AbstractCredentialsFingerprintFacet.timestampRange}: {@code
     * Used {1} ago (first used {0} ago)}.
     * 
     * @param arg1
     *      2nd format parameter, {@code {1}}, as {@link String#valueOf(Object)}.
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Used {1} ago (first used {0} ago)}
     */
    public static Localizable _AbstractCredentialsFingerprintFacet_timestampRange(Object arg0, Object arg1) {
        return new Localizable(holder, "AbstractCredentialsFingerprintFacet.timestampRange", arg0, arg1);
    }

    /**
     * Key {@code AbstractCredentialsFingerprintFacet.timestampSingle}:
     * {@code Used {0} ago}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Used {0} ago}
     */
    public static String AbstractCredentialsFingerprintFacet_timestampSingle(Object arg0) {
        return holder.format("AbstractCredentialsFingerprintFacet.timestampSingle", arg0);
    }

    /**
     * Key {@code AbstractCredentialsFingerprintFacet.timestampSingle}:
     * {@code Used {0} ago}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Used {0} ago}
     */
    public static Localizable _AbstractCredentialsFingerprintFacet_timestampSingle(Object arg0) {
        return new Localizable(holder, "AbstractCredentialsFingerprintFacet.timestampSingle", arg0);
    }

}
